import re
import sys

from six import iteritems

from pandaserver.config import panda_config

from liveconfigparser.LiveConfigParser import LiveConfigParser

# get ConfigParser
tmpConf = LiveConfigParser()

# read
tmpConf.read('panda_jedi.cfg')

# dummy section class
class _SectionClass:
    pass

# loop over all sections
for tmpSection in tmpConf.sections():
    # read section
    tmpDict = getattr(tmpConf,tmpSection)
    # make section class
    tmpSelf = _SectionClass()
    # update module dict
    sys.modules[ __name__ ].__dict__[tmpSection] = tmpSelf
    # expand all values
    for tmpKey,tmpVal in iteritems(tmpDict):
        # convert string to bool/int
        if tmpVal == 'True':
            tmpVal = True
        elif tmpVal == 'False':
            tmpVal = False
        elif tmpVal == 'None':
            tmpVal = None
        elif re.match('^\d+$',tmpVal):
            tmpVal = int(tmpVal)
        # update dict
        setattr(tmpSelf,tmpKey,tmpVal)



import re
from .TaskRefinerBase import TaskRefinerBase

# refiner for general purpose
class GenTaskRefiner (TaskRefinerBase):

    # constructor
    def __init__(self,taskBufferIF,ddmIF):
        TaskRefinerBase.__init__(self,taskBufferIF,ddmIF)

    # extract common parameters
    def extractCommon(self, jediTaskID, taskParamMap, workQueueMapper, splitRule):
        if 'cloud' not in taskParamMap and 'workingGroup' in taskParamMap:
            taskParamMap['cloud'] = taskParamMap['workingGroup']
        if 'transPath' not in taskParamMap:
            taskParamMap['transPath'] = 'https://atlpan.web.cern.ch/atlpan/runGen-00-00-02'
        # set sourceURL
        try:
            if 'sourceURL' in taskParamMap:
                for tmpItem in taskParamMap['jobParameters']:
                    if 'value' in tmpItem:
                        tmpItem['value'] = re.sub('\$\{SURL\}', taskParamMap['sourceURL'], tmpItem['value'])
        except Exception:
            pass
        # update task parameters
        self.updatedTaskParams = taskParamMap
        # call base method
        TaskRefinerBase.extractCommon(self, jediTaskID, taskParamMap, workQueueMapper, splitRule)

    # main
    def doRefine(self,jediTaskID,taskParamMap):
        # normal refine
        self.doBasicRefine(taskParamMap)
        return self.SC_SUCCEEDED
